@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Convert notes and chords to Roman numeral notation
 
-our $VERSION = '0.0701';
+our $VERSION = '0.0800';
 
 use Carp;
 
@@ -60,12 +60,15 @@ sub parse {
     # Get the scale notes
     my @notes = get_scale_notes( $self->scale_note, $self->scale_name );
 
+    # Convert a diminished chord
+    $chord =~ s/dim/o/;
+
     # Get just the note part of the chord name
     ( my $note = $chord ) =~ s/^([A-G][#b]?).*$/$1/;
 
     # Get the roman representation based on the scale position
     my $position = first_index { $_ eq $note } @notes;
-    my ( $roman, $accidental );
+    my $accidental;
     if ( $position == -1 ) {
         if ( length($note) == 1 ) {
             $position = first_index { $_ =~ /$note/ } @notes;
@@ -78,7 +81,7 @@ sub parse {
             $position = first_index { $_ eq $letter } @notes;
         }
     }
-    $roman = $roman[$position];
+    my $roman = $roman[$position];
 
     # Get everything but the note part
     ( my $decorator = $chord ) =~ s/^(?:[A-G][#b]?)(.*)$/$1/;
@@ -95,8 +98,15 @@ sub parse {
     $roman = $accidental . $roman if $accidental;
 
     # Drop the minor and major part of the chord name
-    $decorator =~ s/M//i;
+    if ( $decorator =~ /Maj/ || $decorator =~ /min/ ) {
+        $decorator =~ s/(Maj|min)/ $1/;
+        $decorator = lc $decorator;
+    }
+    else {
+        $decorator =~ s/M//i;
+    }
 
+    # A remaining note name is a bass decorator
     if ( $decorator =~ /([A-G][#b]?)/ ) {
         my $letter = $1;
         $position = first_index { $_ eq $letter } @notes;
@@ -128,7 +138,7 @@ Music::ToRoman - Convert notes and chords to Roman numeral notation
 
 =head1 VERSION
 
-version 0.0701
+version 0.0800
 
 =head1 SYNOPSIS
 
@@ -142,10 +152,12 @@ version 0.0701
   $roman = $mtr->parse('Bo');    # iio (diminished)
   $roman = $mtr->parse('CM');    # III (major)
   $roman = $mtr->parse('C');     # III (major)
+  $roman = $mtr->parse('CMaj7'); # III maj7 (major seventh)
   $roman = $mtr->parse('Em7');   # v7 (minor seventh)
+  $roman = $mtr->parse('Emin7'); # v min7 (minor seventh)
   $roman = $mtr->parse('A+');    # I+ (augmented)
   $roman = $mtr->parse('BbM');   # bII (flat-two major)
-  $roman = $mtr->parse('Cm9/G'); # iii9/VII
+  $roman = $mtr->parse('Cm9/G'); # iii9/VII (minor ninth with a seven in the bass)
 
   # Also:
   $mtr = Music::ToRoman->new(
@@ -227,6 +239,8 @@ assumed.
 If the B<chords> attribute is off and a single note is given, the diatonic mode
 of the B<scale_name> is used to find the correct Roman numeral representation.
 
+A diminished chord may be given as C<dim>, which is then converted to C<o>.
+
 =head1 SEE ALSO
 
 L<Moo>
